Index: webrtc/voice_engine/channel_manager.h |
diff --git a/webrtc/voice_engine/channel_manager.h b/webrtc/voice_engine/channel_manager.h |
index 07cebb0327fb86b90edccf8637c5495c264d2591..f37ce3698bda07007e91e2414242dec8d841a970 100644 |
--- a/webrtc/voice_engine/channel_manager.h |
+++ b/webrtc/voice_engine/channel_manager.h |
@@ -22,6 +22,7 @@ |
namespace webrtc { |
class Config; |
+class RtcEventLog; |
namespace voe { |
@@ -70,7 +71,9 @@ class ChannelOwner { |
class ChannelManager { |
public: |
- ChannelManager(uint32_t instance_id, const Config& config); |
+ ChannelManager(uint32_t instance_id, |
+ const Config& config, |
+ RtcEventLog* const event_log); |
// Upon construction of an Iterator it will grab a copy of the channel list of |
// the ChannelManager. The iteration will then occur over this state, not the |
@@ -94,12 +97,15 @@ class ChannelManager { |
}; |
// CreateChannel will always return a valid ChannelOwner instance. The channel |
// is created either based on internal configuration, i.e. |config_|, by |
// calling CreateChannel(), or using and external configuration |
// |external_config| if the overloaded method |
// CreateChannel(const Config& external_config) is called. |
ChannelOwner CreateChannel(); |
- ChannelOwner CreateChannel(const Config& external_config); |
+ ChannelOwner CreateChannel(const Config& external_config, |
+ RtcEventLog* const event_log); |
// ChannelOwner.channel() will be NULL if channel_id is invalid or no longer |
// exists. This should be checked with ChannelOwner::IsValid(). |
@@ -113,7 +119,8 @@ class ChannelManager { |
private: |
// Create a channel given a configuration, |config|. |
- ChannelOwner CreateChannelInternal(const Config& config); |
+ ChannelOwner CreateChannelInternal(const Config& config, |
+ RtcEventLog* const event_log); |
uint32_t instance_id_; |
@@ -123,6 +130,7 @@ class ChannelManager { |
std::vector<ChannelOwner> channels_; |
const Config& config_; |
+ RtcEventLog* const event_log_; |
DISALLOW_COPY_AND_ASSIGN(ChannelManager); |
}; |
@@ -94,12 +97,15 @@ class ChannelManager { |
}; |
// CreateChannel will always return a valid ChannelOwner instance. The channel |
- // is created either based on internal configuration, i.e. |config_|, by |
- // calling CreateChannel(), or using and external configuration |
- // |external_config| if the overloaded method |
- // CreateChannel(const Config& external_config) is called. |
+ // is created either based on internal configuration, i.e. |config_| and |
+ // |event_log_|, by calling CreateChannel(), or using and external |
+ // configuration |external_config| and external event log |event_log| if the |
+ // overloaded method |
+ // CreateChannel(const Config& external_config, RtcEventLog* const event_log) |
+ // is called. |
ChannelOwner CreateChannel(); |